@@ -5,7 +5,7 @@ import logging
 from pathlib import Path
 from typing import Any, Dict, Optional, Tuple
 
-from PIL import Image, ImageDraw
+from PIL import Image
 
 from ..exceptions import DeviceFrameError
 
@@ -426,7 +426,8 @@ class DeviceFrameRenderer:
                         mask_pixels[x, y] = 255  # White = show content
 
             logger.info(
-                "📱 Flood fill completed: {len(visited)} pixels marked as outside, {(frame_width*frame_height-len(visited))} as screen area"
+                f"📱 Flood fill completed: {len(visited)} pixels marked as outside, "
+                f"{(frame_width*frame_height-len(visited))} as screen area"
             )
 
             logger.info(
@@ -514,7 +515,9 @@ class DeviceFrameRenderer:
             # Apply mask to canvas: only show content where mask is white
             masked_canvas = Image.composite(canvas_image, transparent_bg, canvas_mask)
 
-            logger.info(f"📱 Applied screen mask to canvas at position {asset_position}")
+            logger.info(
+                f"📱 Applied screen mask to canvas at position {asset_position}"
+            )
             return masked_canvas
 
         except Exception as _e:
